publicidad
==========

This is the main index page of your documentation. It should be written in
`reStructuredText format <http://docutils.sourceforge.net/rst.html>`_.


:mod:`publicidad`
-----------------

.. automodule:: publicidad
